@@ -5,17 +5,16 @@
 # count - number of observations to create
 # filter - function to apply
 # replace - whether to use replacement in bootstrapping
-# divergence(sp500.subset, 25, filter=getCorFilter.RMT())
-# divergence(sp500.subset, 25, filter=getCorFilter.Shrinkage())
+# divergence(sp500.subset, 25, filter=RandomMatrixDenoiser())
+# divergence(sp500.subset, 25, filter=ShrinkageDenoiser())
 # Can measure information (the default) or stability. Measuring stability will
 # resample twice to get two forms of the correlation matrix.
-#### TODO
-# Add %default% operator
-# Handle ... in default
-deform %when% (Type == 'matrix')
-deform %also% (object %isa% AssetReturns)
-deform %as% function(object, Type) # Auto number the functions
-{
+
+#### TODO - Rethink this API
+deform(object, type) %::% AssetReturns : character : matrix
+deform(object, type) %when% {
+  type == 'matrix'
+} %as% {
   col.names <- colnames(object)
   row.names <- format(index(object), '%Y-%m-%d')
   h <- matrix(object, ncol=ncol(object))
@@ -24,10 +23,10 @@ deform %as% function(object, Type) # Auto number the functions
   h
 }
 
-deform %when% (Type == 'matrix')
-deform %also% (object %isa% zoo)
-deform %as% function(object, Type) # Auto number the functions
-{
+deform(object, type) %::% zoo : character : matrix
+deform(object, type) %when% {
+  type == 'matrix'
+} %as% {
   col.names <- colnames(object)
   row.names <- format(index(object), '%Y-%m-%d')
   h <- matrix(object, ncol=ncol(object))
@@ -36,25 +35,28 @@ deform %as% function(object, Type) # Auto number the functions
   h
 }
 
-divergence %when% (ret %isa% zoo)
-divergence %as% function(ret, count, filter)
-{
-  p <- create(TawnyPortfolio, ret, nrow(ret))
+KullbackLeibler(...) %as% { list(...) }
+
+divergence(ret, count, filter) %when% {
+  ret %isa% zoo
+} %as% {
+  p <- TawnyPortfolio(ret, as.numeric(nrow(ret)))
   divergence(p, count, filter)
 }
 
-divergence %when% (p %hasa% returns)
-divergence %also% is.function(filter)
-divergence %as% function(p, count, filter)
-{
-  divergence(p, count, filter, create(KullbackLeibler, measure='information'))
+divergence(p, count, filter) %when% {
+  p %hasa% returns
+  is.function(filter)
+} %as% {
+  divergence(p, count, filter, KullbackLeibler(measure='information'))
 }
 
-divergence %when% (p %hasa% returns)
-divergence %also% (algo %isa% KullbackLeibler & algo$measure=='information')
-divergence %as% function(p, count, filter, algo)
-{
-  logger(INFO, sprintf("Row names: %s", rownames(p$returns)))
+divergence(p, count, filter, algo) %when% {
+  p %hasa% returns
+  algo %isa% KullbackLeibler
+  algo$measure=='information'
+} %as% {
+  flog.debug("Row names: %s", rownames(p$returns))
   # Convert to matrix to allow duplicates
   h <- deform(p$returns,'matrix')
   if (is.null(p$window)) { p$window <- anylength(h) }
@@ -64,7 +66,7 @@ divergence %as% function(p, count, filter, algo)
   {
     h.window <- h.full[sample(index(h.full), p$window, replace=TRUE), ]
     c.sample <- cov2cor(cov.sample(h.window))
-    p <- create(TawnyPortfolio, zoo(h.window, rownames(h.window)), p$window)
+    p <- TawnyPortfolio(zoo(h.window, rownames(h.window)), p$window)
     c.model <- filter(p)
 
     divergence <- divergence.kl(c.sample, c.model)
@@ -73,7 +75,7 @@ divergence %as% function(p, count, filter, algo)
   ds <- sapply(1:count, div, h)
 
   theory <- divergence_lim(ncol(h), p$window, algo)
-  #cat("Theoretical divergence is",theory,"\n")
+  flog.trace("Theoretical divergence is %s",theory)
 
   return(c(mean=mean(ds, na.rm=TRUE), sd=sd(ds, na.rm=TRUE), limit=theory))
 }
@@ -116,7 +118,7 @@ divergence %as% function(p, count, filter, algo)
 # correlation matrix
 # Measuring stability averages all permutations of the KL divergence of two
 # instances of the filtered correlation matrix
-divergence.kl <- function(sigma.1, sigma.2)
+divergence.kl(sigma.1, sigma.2) %as%
 {
   term.1 <- log(det(sigma.2) / det(sigma.1))
   term.2 <- sum(diag(solve(sigma.2) %*% sigma.1))
@@ -125,15 +127,15 @@ divergence.kl <- function(sigma.1, sigma.2)
 
 # The expected value of the divergence for random matrices (sample versus 
 # true correlation matrix)
-divergence_lim %when% (model %isa% KullbackLeibler)
-divergence_lim %as% function(ps, model)
-{
+divergence_lim(ps, model) %when% {
+  model %isa% KullbackLeibler
+} %as% {
   divergence_lim(ps[1], ps[2], model)
 }
 
-divergence_lim %when% (model %isa% KullbackLeibler)
-divergence_lim %as% function(m, t, model)
-{
+divergence_lim(m, t, model) %when% {
+  model %isa% KullbackLeibler
+} %as% {
   l <- t - m + 1
   0.5 * ( m * log(t/2) - sum(digamma((l:t)/2)) )
 }
@@ -141,9 +143,9 @@ divergence_lim %as% function(m, t, model)
 # plotDivergenceLimit.kl(100, 80:499, col='green', ylim=c(0,55))
 # plotDivergenceLimit.kl(80, 80:499, col='orange', overlay=TRUE)
 # plotDivergenceLimit.kl(40, 80:499, col='red', overlay=TRUE)
-plotDivergenceLimit.kl <- function(m, t.range, ..., overlay=FALSE)
+plotDivergenceLimit.kl(m, t.range, ..., overlay=FALSE) %as%
 {
-  model <- create(KullbackLeibler)
+  model <- KullbackLeibler()
   ns <- rep(m,length(t.range))
   limit <- apply(matrix(c(ns, t.range), ncol=2), 1, 
     function(m) divergence_lim(m, model))
@@ -161,20 +163,22 @@ plotDivergenceLimit.kl <- function(m, t.range, ..., overlay=FALSE)
 }
 
 # Limit for stability (distance between two sample correlation matrices)
-stability_lim %when% (model %isa% KullbackLeibler)
-stability_lim %as% function(m, t=NULL, model)
-{ 
-  if (is.null(t))
-  {
-    t <- m[2]
-    m <- m[1]
-  } 
+stability_lim(m, model) %::% a : KullbackLeibler : a
+stability_lim(m, model) %as%
+{
+  t <- m[2]
+  m <- m[1]
+  stability_lim(m, t, model)
+}
 
+stability_lim(m, t, model) %::% a : a : KullbackLeibler : a
+stability_lim(m, t, model) %as%
+{ 
   0.5 * m * (m+1) / (t - m - 1)
 }
 
 # Determine the stability of the filter.
-divergence.stability <- function(h, count, window, filter)
+divergence.stability(h, count, window, filter) %as%
 {
   if (is.null(window)) { window <- anylength(h) }
   # Convert to matrix to allow duplicates
